@@ -17,13 +17,14 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * (C) Copyright 2008 - 2011 Red Hat, Inc.
+ * (C) Copyright 2008 - 2012 Red Hat, Inc.
  */
 
+#include "config.h"
+
 #include <string.h>
 #include <errno.h>
 #include <stdlib.h>
-#include <arpa/inet.h>
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
@@ -369,7 +370,6 @@ populate_ui (CEPageIP4 *self)
 		NMIP4Address *addr = nm_setting_ip4_config_get_address (setting, i);
 		struct in_addr tmp_addr;
 		char buf[INET_ADDRSTRLEN + 1];
-		const char *ignored;
 
 		if (!addr) {
 			g_warning ("%s: empty IP4 Address structure!", __func__);
@@ -379,15 +379,15 @@ populate_ui (CEPageIP4 *self)
 		gtk_list_store_append (store, &model_iter);
 
 		tmp_addr.s_addr = nm_ip4_address_get_address (addr);
-		ignored = inet_ntop (AF_INET, &tmp_addr, &buf[0], sizeof (buf));
+		(void) inet_ntop (AF_INET, &tmp_addr, &buf[0], sizeof (buf));
 		gtk_list_store_set (store, &model_iter, COL_ADDRESS, buf, -1);
 
 		tmp_addr.s_addr = nm_utils_ip4_prefix_to_netmask (nm_ip4_address_get_prefix (addr));
-		ignored = inet_ntop (AF_INET, &tmp_addr, &buf[0], sizeof (buf));
+		(void) inet_ntop (AF_INET, &tmp_addr, &buf[0], sizeof (buf));
 		gtk_list_store_set (store, &model_iter, COL_PREFIX, buf, -1);
 
 		tmp_addr.s_addr = nm_ip4_address_get_gateway (addr);
-		ignored = inet_ntop (AF_INET, &tmp_addr, &buf[0], sizeof (buf));
+		(void) inet_ntop (AF_INET, &tmp_addr, &buf[0], sizeof (buf));
 		gtk_list_store_set (store, &model_iter, COL_GATEWAY, buf, -1);
 	}
 
@@ -401,13 +401,12 @@ populate_ui (CEPageIP4 *self)
 	for (i = 0; i < nm_setting_ip4_config_get_num_dns (setting); i++) {
 		struct in_addr tmp_addr;
 		char buf[INET_ADDRSTRLEN + 1];
-		const char *ignored;
 
 		tmp_addr.s_addr = nm_setting_ip4_config_get_dns (setting, i);
 		if (!tmp_addr.s_addr)
 			continue;
 
-		ignored = inet_ntop (AF_INET, &tmp_addr, &buf[0], sizeof (buf));
+		(void) inet_ntop (AF_INET, &tmp_addr, &buf[0], sizeof (buf));
 		if (string->len)
 			g_string_append (string, ", ");
 		g_string_append (string, buf);
@@ -835,7 +834,6 @@ routes_button_clicked_cb (GtkWidget *button, gpointer user_data)
 	g_free (tmp);
 
 	g_signal_connect (G_OBJECT (dialog), "response", G_CALLBACK (routes_dialog_response_cb), self);
-	g_signal_connect (G_OBJECT (dialog), "close", G_CALLBACK (routes_dialog_close_cb), self);
 
 	gtk_widget_show_all (dialog);
 }
@@ -883,16 +881,12 @@ finish_setup (CEPageIP4 *self, gpointer unused, GError *error, gpointer user_dat
 	gint offset;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *renderer;
-	GtkListStore *store;
 
 	if (error)
 		return;
 
 	populate_ui (self);
 
-	/* Address column */
-	store = GTK_LIST_STORE (gtk_tree_view_get_model (priv->addr_list));
-
 	/* IP Address column */
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "editable", TRUE, NULL);
@@ -970,6 +964,7 @@ finish_setup (CEPageIP4 *self, gpointer unused, GError *error, gpointer user_dat
 CEPage *
 ce_page_ip4_new (NMConnection *connection,
                  GtkWindow *parent_window,
+                 NMClient *client,
                  const char **out_secrets_setting_name,
                  GError **error)
 {
@@ -980,6 +975,7 @@ ce_page_ip4_new (NMConnection *connection,
 	self = CE_PAGE_IP4 (ce_page_new (CE_TYPE_PAGE_IP4,
 	                                 connection,
 	                                 parent_window,
+	                                 client,
 	                                 UIDIR "/ce-page-ip4.ui",
 	                                 "IP4Page",
 	                                 _("IPv4 Settings")));
